@@ -85,7 +85,7 @@ class Deployer(object):
         if os.path.exists(build_path):
             shutil.rmtree(build_path)
 
-        os.mkdir(build_path)
+        os.makedirs(build_path, exist_ok=True)
 
         # Install requirements.
         pip_cmd = ["pip", "install", "-r", "requirements.txt", "-t", build_path]
